@@ -126,11 +126,25 @@ function _fbiterm_ok {
     return 0
 }
 
+function dialog_timeout {
+    local timeout=60
+    custom_timeout=$(getarg "rd.kiwi.dialog.timeout=")
+    [ -n "${custom_timeout}" ] && timeout="${custom_timeout}"
+    echo "${timeout}"
+}
+
 function show_log_and_quit {
     local text_message="$1"
     local log_file="$2"
-    run_dialog --timeout 60 --backtitle "\"${text_message}\"" \
-        --textbox "${log_file}" 15 80
+    local timeout
+    timeout=$(dialog_timeout)
+    if [ "${timeout}" = "off" ];then
+        run_dialog --backtitle "\"${text_message}\"" \
+            --textbox "${log_file}" 15 80
+    else
+        run_dialog --timeout "${timeout}" --backtitle "\"${text_message}\"" \
+            --textbox "${log_file}" 15 80
+    fi
     if getargbool 0 rd.debug; then
         die "${text_message}"
     else
@@ -140,7 +154,13 @@ function show_log_and_quit {
 
 function report_and_quit {
     local text_message="$1"
-    run_dialog --timeout 60 --msgbox "\"${text_message}\"" 5 80
+    local timeout
+    timeout=$(dialog_timeout)
+    if [ "${timeout}" = "off" ];then
+        run_dialog --msgbox "\"${text_message}\"" 5 80
+    else
+        run_dialog --timeout "${timeout}" --msgbox "\"${text_message}\"" 5 80
+    fi
     if getargbool 0 rd.debug; then
         die "${text_message}"
     else
@@ -165,3 +185,8 @@ function ask_and_shutdown {
         systemctl halt
     fi
 }
+
+function ask_for_credentials {
+    local text_message="$1"
+    run_dialog --insecure --passwordbox "\"${text_message}\"" 7 60
+}
