@@ -61,7 +61,9 @@ function get_volume_path_for_volume {
 }
 
 function resize_pyhiscal_volumes {
-    pvresize "$(get_root_map)"
+    local device
+    device=$(get_root_map)
+    udevadm lock --device "${device}" pvresize "${device}"
 }
 
 function resize_lvm_volumes_and_filesystems {
