@@ -22,8 +22,8 @@ install() {
         e2fsck btrfsck xfs_repair \
         vgs vgchange lvextend lvcreate lvresize pvresize \
         mdadm cryptsetup dialog \
-        pv curl xz \
-        dmsetup
+        pv curl xz sha256sum sed \
+        dmsetup touch chmod
     inst_multiple -o dolly
     if type partx &> /dev/null;then
         inst_multiple partx
