@@ -34,6 +34,7 @@ from kiwi.filesystem.isofs import FileSystemIsoFs
 from kiwi.firmware import FirmWare
 from kiwi.system.identifier import SystemIdentifier
 from kiwi.path import Path
+from kiwi.utils.block import BlockID
 from kiwi.defaults import Defaults
 from kiwi.utils.checksum import Checksum
 from kiwi.system.kernel import Kernel
@@ -119,8 +120,8 @@ class InstallImageBuilder:
         self.squashed_diskname = ''.join(
             [xml_state.xml_data.get_name(), '.raw']
         )
-        self.md5name = ''.join(
-            [xml_state.xml_data.get_name(), '.md5']
+        self.sha256name = ''.join(
+            [xml_state.xml_data.get_name(), '.sha256']
         )
         self.xz_options = custom_args['xz_options'] if custom_args \
             and 'xz_options' in custom_args else None
@@ -161,6 +162,8 @@ class InstallImageBuilder:
                 'mbr_id': self.mbrid.get_id(),
                 'application_id': self.xml_state.build_type.get_application_id(),
                 'efi_mode': self.firmware.efi_mode(),
+                'efi_partition_table': self.firmware.get_partition_table_type(),
+                'gpt_hybrid_mbr': self.firmware.gpt_hybrid_mbr,
                 'ofw_mode': self.firmware.ofw_mode(),
                 'legacy_bios_mode': self.firmware.legacy_bios_mode()
             }
@@ -172,7 +175,7 @@ class InstallImageBuilder:
             prefix='kiwi_install_squashfs.', path=self.target_dir
         ).new_dir()
         checksum = Checksum(self.diskname)
-        checksum.md5(self.squashed_contents.name + '/' + self.md5name)
+        checksum.sha256(self.squashed_contents.name + '/' + self.sha256name)
 
         # the system image name is stored in a config file
         self._write_install_image_info_to_iso_image()
@@ -289,14 +292,14 @@ class InstallImageBuilder:
 
         # the system image transfer is checked against a checksum
         log.info('Creating disk image checksum')
-        pxe_md5_filename = ''.join(
+        pxe_sha256_filename = ''.join(
             [
                 self.pxe_dir.name, '/',
-                self.pxename, '.md5'
+                self.pxename, '.sha256'
             ]
         )
         checksum = Checksum(self.diskname)
-        checksum.md5(pxe_md5_filename)
+        checksum.sha256(pxe_sha256_filename)
 
         # the install image name is stored in a config file
         if self.initrd_system == 'kiwi':
@@ -336,7 +339,7 @@ class InstallImageBuilder:
         if custom_cmdline:
             cmdline += ' ' + custom_cmdline
         with open(append_filename, 'w') as append:
-            append.write('%s\n' % cmdline)
+            append.write(f'{cmdline}\n')
 
         # create initrd for pxe install
         log.info('Creating pxe install boot image')
@@ -410,6 +413,11 @@ class InstallImageBuilder:
             self.boot_image_task.set_static_modules(
                 self.xml_state.get_installmedia_initrd_modules('set')
             )
+            for drv in self.xml_state.get_installmedia_initrd_drivers('add'):
+                self.boot_image_task.include_driver(drv)
+            for drv in self.xml_state.get_installmedia_initrd_drivers('omit'):
+                self.boot_image_task.omit_driver(drv)
+
         self.boot_image_task.create_initrd(
             self.mbrid, 'initrd_kiwi_install',
             install_initrd=True
@@ -453,7 +461,14 @@ class InstallImageBuilder:
             self.boot_image_task.set_static_modules(
                 self.xml_state.get_installmedia_initrd_modules('set')
             )
+
+            for drv in self.xml_state.get_installmedia_initrd_drivers('add'):
+                self.boot_image_task.include_driver(drv)
+            for drv in self.xml_state.get_installmedia_initrd_drivers('omit'):
+                self.boot_image_task.omit_driver(drv)
+
             self._add_system_image_boot_options_to_boot_image()
+            self._add_system_identifier_to_boot_image()
         self.boot_image_task.create_initrd(
             self.mbrid, 'initrd_kiwi_install',
             install_initrd=True
@@ -465,6 +480,15 @@ class InstallImageBuilder:
             ]
         )
 
+    def _add_system_identifier_to_boot_image(self) -> None:
+        filename = ''.join(
+            [self.boot_image_task.boot_root_directory, '/system_identifier']
+        )
+        blockid = BlockID(self.diskname)
+        with open(filename, 'w') as system_identifier:
+            system_identifier.write(blockid.get_ptuuid())
+        self.boot_image_task.include_file(os.sep + os.path.basename(filename))
+
     def _add_system_image_boot_options_to_boot_image(self) -> None:
         filename = ''.join(
             [self.boot_image_task.boot_root_directory, '/config.bootoptions']
@@ -483,10 +507,10 @@ class InstallImageBuilder:
     def _write_install_image_info_to_iso_image(self) -> None:
         iso_trigger = self.media_dir.name + '/config.isoclient'
         with open(iso_trigger, 'w') as iso_system:
-            iso_system.write('IMAGE="%s"\n' % self.squashed_diskname)
+            iso_system.write(f'IMAGE="{self.squashed_diskname}\"\n')
 
     def _write_install_image_info_to_boot_image(self) -> None:
         initrd_trigger = \
             self.boot_image_task.boot_root_directory + '/config.vmxsystem'
         with open(initrd_trigger, 'w') as vmx_system:
-            vmx_system.write('IMAGE="%s"\n' % self.squashed_diskname)
+            vmx_system.write(f'IMAGE="{self.squashed_diskname}\"\n')
