@@ -144,6 +144,8 @@ class LiveImageBuilder:
                 'mbr_id': self.mbrid.get_id(),
                 'application_id': self.application_id,
                 'efi_mode': self.firmware.efi_mode(),
+                'efi_partition_table': self.firmware.get_partition_table_type(),
+                'gpt_hybrid_mbr': self.firmware.gpt_hybrid_mbr,
                 'legacy_bios_mode': self.firmware.legacy_bios_mode()
             }
         }
@@ -301,17 +303,20 @@ class LiveImageBuilder:
                 )
         else:
             # Put the root filesystem into SquashFS directly
-            with FileSystem.new(
-                name=root_filesystem,
-                device_provider=DeviceProvider(),
-                root_dir=self.root_dir + os.sep,
-                custom_args={
+            filesystem_custom_parameters.update(
+                {
                     'compression':
                         self.xml_state.build_type.get_squashfscompression()
                 } if root_filesystem == 'squashfs' else {
                     'compression':
                         self.xml_state.build_type.get_erofscompression()
                 }
+            )
+            with FileSystem.new(
+                name=root_filesystem,
+                device_provider=DeviceProvider(),
+                root_dir=self.root_dir + os.sep,
+                custom_args=filesystem_custom_parameters
             ) as live_container_image:
                 container_image = Temporary().new_file()
                 live_container_image.create_on_file(
