@@ -952,6 +952,10 @@ class Defaults:
                 '/boot/efi/EFI/*/shimaa64.efi',
                 'bootaa64.efi'
             ),
+            shim_pattern_type(
+                '/boot/efi/EFI/*/shimriscv64.efi',
+                'bootriscv64.efi'
+            ),
             shim_pattern_type(
                 '/boot/efi/EFI/*/shim.efi',
                 'bootx64.efi'
@@ -1062,6 +1066,11 @@ class Defaults:
                     '/boot/efi/EFI/*/grubaa64.efi',
                     'grubaa64.efi',
                     'bootaa64.efi'
+                ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/grubriscv64.efi',
+                    'grubriscv64.efi',
+                    'bootriscv64.efi'
                 )
             ],
             'iso': [
@@ -1094,6 +1103,11 @@ class Defaults:
                     '/boot/efi/EFI/*/grubaa64.efi',
                     'grubaa64.efi',
                     'bootaa64.efi'
+                ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/grubriscv64.efi',
+                    'grubriscv64.efi',
+                    'bootriscv64.efi'
                 )
             ]
         }
@@ -1234,6 +1248,11 @@ class Defaults:
                     'grubaa64.efi',
                     'bootaa64.efi'
                 ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/grubriscv64.efi',
+                    'grubriscv64.efi',
+                    'bootriscv64.efi'
+                ),
                 grub_pattern_type(
                     '/usr/share/grub*/*-efi/grub.efi',
                     'grub.efi',
@@ -1286,6 +1305,11 @@ class Defaults:
                     'grubaa64.efi',
                     'bootaa64.efi'
                 ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/grubriscv64.efi',
+                    'grubriscv64.efi',
+                    'bootriscv64.efi'
+                ),
                 grub_pattern_type(
                     '/usr/share/grub*/x86_64-efi/grub.efi',
                     'grub.efi',
