@@ -98,6 +98,17 @@ class PartitionerBase:
         """
         raise NotImplementedError
 
+    def set_uuid(self, partition_id: int, uuid: str):
+        """
+        Set partition UUID
+
+        Implementation in specialized partitioner class
+
+        :param int partition_id: unused
+        :param string uuid: unused
+        """
+        raise NotImplementedError
+
     def set_hybrid_mbr(self):
         """
         Turn partition table into hybrid table if supported
