@@ -65,8 +65,8 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             self.custom_args = {}
         if 'root_label' not in self.custom_args:
             self.custom_args['root_label'] = 'ROOT'
-        if 'root_is_snapshot' not in self.custom_args:
-            self.custom_args['root_is_snapshot'] = False
+        if 'root_is_snapper_snapshot' not in self.custom_args:
+            self.custom_args['root_is_snapper_snapshot'] = False
         if 'btrfs_default_volume_requested' not in self.custom_args:
             self.custom_args['btrfs_default_volume_requested'] = True
         if 'root_is_readonly_snapshot' not in self.custom_args:
@@ -86,14 +86,15 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                     self.root_volume_name = volume.name
                     self.default_volume_name = self.root_volume_name
 
-        if self.custom_args['root_is_snapshot'] and \
+        if self.custom_args['root_is_snapper_snapshot'] and \
            self.root_volume_name == '/':
-            log.warning('root_is_snapshot requires a toplevel sub-volume')
-            log.warning('root_is_snapshot has been disabled')
-            self.custom_args['root_is_snapshot'] = False
+            log.warning('root_is_snapper_snapshot requires a toplevel sub-volume')
+            log.warning('root_is_snapper_snapshot has been disabled')
+            self.custom_args['root_is_snapper_snapshot'] = False
 
         self.subvol_mount_list = []
         self.toplevel_mount = None
+        self.snapshots_root_mount = None
 
     def setup(self, name=None):
         """
@@ -134,7 +135,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             Command.run(
                 ['btrfs', 'subvolume', 'create', root_volume]
             )
-        if self.custom_args['root_is_snapshot']:
+        if self.custom_args['root_is_snapper_snapshot']:
             snapshot_volume = self.mountpoint + \
                 f'/{self.root_volume_name}/.snapshots'
             Command.run(
@@ -162,6 +163,10 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 mountpoint=snapshot + '/.snapshots'
             )
             self.subvol_mount_list.append(snapshots_mount)
+            # make sure the snapshot appears as proper (/) in the chroot
+            self.snapshots_root_mount = MountManager(
+                device=self.get_mountpoint(), mountpoint=self.get_mountpoint()
+            )
         elif self.root_volume_name != '/':
             self._set_default_volume(self.root_volume_name)
 
@@ -233,7 +238,8 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 )
 
                 volume_mountpoint = toplevel
-                root_is_snapshot = self.custom_args['root_is_snapshot']
+                root_is_snapper_snapshot = \
+                    self.custom_args['root_is_snapper_snapshot']
 
                 attributes = {
                     'parent': volume.parent or '',
@@ -244,7 +250,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                     ).lstrip(os.sep),
                     'subvol_name': volume.name
                 }
-                if root_is_snapshot:
+                if root_is_snapper_snapshot:
                     volume_mountpoint = self.mountpoint + \
                         f'/{self.root_volume_name}/.snapshots/1/snapshot/'
                     attributes = {
@@ -263,7 +269,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                         os.sep.join(
                             [
                                 volume_mountpoint,
-                                self.root_volume_name if not root_is_snapshot else '',
+                                self.root_volume_name if not root_is_snapper_snapshot else '',
                                 volume.realpath
                             ]
                         )
@@ -361,6 +367,8 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         for volume_mount in self.subvol_mount_list:
             if not os.path.exists(volume_mount.mountpoint):
                 Path.create(volume_mount.mountpoint)
+            if self.snapshots_root_mount:
+                self.snapshots_root_mount.bind_mount()
             subvol_path = volume_mount.get_attributes().get('subvol_path')
             subvol_options = ','.join(
                 [
@@ -379,6 +387,9 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             if volume_mount.is_mounted():
                 volume_mount.umount()
 
+        if self.snapshots_root_mount and self.snapshots_root_mount.is_mounted():
+            self.snapshots_root_mount.umount()
+
         if self.toplevel_mount.is_mounted():
             self.toplevel_mount.umount()
 
@@ -397,7 +408,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         sync_target: List[str] = [self.mountpoint]
         if self.root_volume_name != '/':
             sync_target.append(self.root_volume_name)
-        if self.custom_args.get('root_is_snapshot'):
+        if self.custom_args.get('root_is_snapper_snapshot'):
             sync_target.extend(['.snapshots', '1', 'snapshot'])
         return os.path.join(*sync_target)
 
@@ -412,7 +423,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         """
         if self.toplevel_mount:
             sync_target = self.get_mountpoint()
-            if self.custom_args['root_is_snapshot']:
+            if self.custom_args['root_is_snapper_snapshot']:
                 self._create_snapshot_info(
                     ''.join(
                         [
@@ -426,18 +437,18 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 options=Defaults.get_sync_options(), exclude=exclude
             )
             if self.custom_args['quota_groups'] and \
-               self.custom_args['root_is_snapshot']:
+               self.custom_args['root_is_snapper_snapshot']:
                 self._create_snapper_quota_configuration()
 
     def set_property_readonly_root(self):
         """
         Sets the root volume to be a readonly filesystem
         """
-        root_is_snapshot = \
-            self.custom_args['root_is_snapshot']
+        root_is_snapper_snapshot = \
+            self.custom_args['root_is_snapper_snapshot']
         root_is_readonly_snapshot = \
             self.custom_args['root_is_readonly_snapshot']
-        if root_is_snapshot and root_is_readonly_snapshot:
+        if root_is_snapper_snapshot and root_is_readonly_snapshot:
             sync_target = self.get_mountpoint()
             Command.run(
                 ['btrfs', 'property', 'set', sync_target, 'ro', 'true']
@@ -499,7 +510,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                     return
 
         raise KiwiVolumeRootIDError(
-            'Failed to find btrfs volume: %s' % default_volume
+            f'Failed to find btrfs volume: {default_volume}'
         )
 
     def _xml_pretty(self, toplevel_element):
