@@ -1,21 +1,17 @@
 from pytest_container.container import DerivedContainer
 from .conftest import (
-    CENTOS_STREAM_8,
-    LEAP_15_2,
-    LEAP_15_3,
-    TUMBLEWEED,
+    CONTAINERS_WITH_ZYPPER,
+    CONTAINERS_WITH_DNF
 )
 import pytest
 
 
-VAGRANT_SETUP_CONTAINERFILE = (
-    r"""RUN groupadd vagrant && useradd -g vagrant vagrant
+VAGRANT_SETUP_CONTAINERFILE = r"""RUN groupadd vagrant && useradd -g vagrant vagrant
 RUN echo $'#!/bin/bash \n\
 printf "%s " "$@" >> /systemctl_params \n\
 echo >> /systemctl_params \n\
 '> /usr/bin/systemctl && chmod +x /usr/bin/systemctl
 """
-)
 
 ZYPPER_IN_CMD_CONTAINERFILE = (
     """RUN zypper -n in openssh sudo && /usr/sbin/sshd-gen-keys-start
@@ -23,18 +19,21 @@ ZYPPER_IN_CMD_CONTAINERFILE = (
 )
 
 
+DNF_IN_CMD_CONTAINERFILE = (
+    """RUN dnf -y install openssh-server && /usr/libexec/openssh/sshd-keygen ed25519
+""" + VAGRANT_SETUP_CONTAINERFILE
+)
+
+
 @pytest.mark.parametrize(
     "container_per_test",
-    (
-        DerivedContainer(base=TUMBLEWEED, containerfile=ZYPPER_IN_CMD_CONTAINERFILE),
-        DerivedContainer(base=LEAP_15_2, containerfile=ZYPPER_IN_CMD_CONTAINERFILE),
-        DerivedContainer(base=LEAP_15_3, containerfile=ZYPPER_IN_CMD_CONTAINERFILE),
-        DerivedContainer(
-            base=CENTOS_STREAM_8,
-            containerfile="""RUN yum -y install openssh-server sudo && /usr/libexec/openssh/sshd-keygen ed25519
-""" + VAGRANT_SETUP_CONTAINERFILE,
-        ),
-    ),
+    [
+        DerivedContainer(base=cont, containerfile=ZYPPER_IN_CMD_CONTAINERFILE)
+        for cont in CONTAINERS_WITH_ZYPPER
+    ] + [
+        DerivedContainer(base=cont, containerfile=DNF_IN_CMD_CONTAINERFILE)
+        for cont in CONTAINERS_WITH_DNF
+    ],
     indirect=["container_per_test"],
 )
 def test_configures_system_for_vagrant(container_per_test):
@@ -59,9 +58,9 @@ def test_configures_system_for_vagrant(container_per_test):
     assert "vagrant insecure public key" in authorized_keys.content_string
 
     # check the sshd config
-    sshd_config = container_per_test.connection.run_expect([0], "sshd -T")
-    assert "UseDNS no".lower() in sshd_config.stdout
-    assert "GSSAPIAuthentication no".lower() in sshd_config.stdout
+    sshd_config = container_per_test.connection.run_expect([0], "sshd -T").stdout
+    assert "UseDNS no".lower() in sshd_config
+    assert "GSSAPIAuthentication no".lower() in sshd_config
 
     # check that the shared /vagrant folder is present and has the correct permissions
     vagrant_shared_dir = container_per_test.connection.file("/vagrant")
