@@ -74,6 +74,9 @@ class TestInstallImageBuilder:
         self.xml_state.get_installmedia_initrd_modules = mock.Mock(
             return_value=['module1', 'module2']
         )
+        self.xml_state.get_installmedia_initrd_drivers = mock.Mock(
+            return_value=['driver1', 'driver2']
+        )
         self.boot_image_task = mock.Mock()
         self.boot_image_task.boot_root_directory = 'initrd_dir'
         self.boot_image_task.initrd_filename = 'initrd'
@@ -129,11 +132,15 @@ class TestInstallImageBuilder:
     @patch('kiwi.builder.install.Temporary')
     @patch('kiwi.builder.install.Command.run')
     @patch('kiwi.builder.install.Defaults.get_grub_boot_directory_name')
+    @patch('kiwi.builder.install.BlockID.get_ptuuid')
     def test_create_install_iso(
-        self, mock_grub_dir, mock_command, mock_Temporary, mock_copy,
-        mock_setup_media_loader_directory, mock_create_boot_loader_config,
-        mock_DeviceProvider, mock_FileSystemSquashFs, mock_FileSystemIsoFs
+        self, mock_get_ptuuid, mock_grub_dir, mock_command, mock_Temporary,
+        mock_copy, mock_setup_media_loader_directory,
+        mock_create_boot_loader_config, mock_DeviceProvider,
+        mock_FileSystemSquashFs, mock_FileSystemIsoFs
     ):
+        mock_get_ptuuid.return_value = 'some_PTUUID'
+
         temp_squashfs = Mock()
         temp_squashfs.new_dir.return_value.name = 'temp-squashfs'
 
@@ -163,8 +170,8 @@ class TestInstallImageBuilder:
 
         self.setup.import_cdroot_files.assert_called_once_with('temp_media_dir')
 
-        self.checksum.md5.assert_called_once_with(
-            'temp-squashfs/result-image.md5'
+        self.checksum.sha256.assert_called_once_with(
+            'temp-squashfs/result-image.sha256'
         )
         mock_copy.assert_called_once_with(
             'root_dir/boot/initrd-kernel_version',
@@ -246,6 +253,8 @@ class TestInstallImageBuilder:
 
         self.boot_image_task.include_module.assert_any_call('kiwi-dump')
         self.boot_image_task.include_module.assert_any_call('kiwi-dump-reboot')
+        self.boot_image_task.include_driver.assert_any_call('driver1')
+        self.boot_image_task.include_driver.assert_any_call('driver2')
         assert self.boot_image_task.omit_module.call_args_list == [
             call('multipath'), call('module1'), call('module2')
         ]
@@ -253,14 +262,17 @@ class TestInstallImageBuilder:
             ['module1', 'module2']
         )
 
-        self.boot_image_task.include_file.assert_called_once_with(
-            '/config.bootoptions'
-        )
+        assert self.boot_image_task.include_file.call_args_list == [
+            call('/config.bootoptions'),
+            call('/system_identifier')
+        ]
         assert m_open.call_args_list == [
             call('temp_media_dir/config.isoclient', 'w'),
+            call('initrd_dir/system_identifier', 'w')
         ]
         assert m_open.return_value.write.call_args_list == [
-            call('IMAGE="result-image.raw"\n')
+            call('IMAGE="result-image.raw"\n'),
+            call('some_PTUUID')
         ]
 
     @patch('kiwi.builder.disk.create_boot_loader_config')
@@ -296,7 +308,7 @@ class TestInstallImageBuilder:
     @patch('kiwi.builder.install.Checksum')
     @patch('kiwi.builder.install.Compress')
     def test_create_install_pxe_no_kernel_found(
-        self, mock_compress, mock_md5, mock_command, mock_Temporary
+        self, mock_compress, mock_sha256, mock_command, mock_Temporary
     ):
         self.firmware.bios_mode.return_value = False
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
@@ -311,7 +323,7 @@ class TestInstallImageBuilder:
     @patch('kiwi.builder.install.Compress')
     @patch('kiwi.builder.install.os.symlink')
     def test_create_install_pxe_no_hypervisor_found(
-        self, mock_symlink, mock_compress, mock_md5, mock_command,
+        self, mock_symlink, mock_compress, mock_sha256, mock_command,
         mock_Temporary
     ):
         self.firmware.bios_mode.return_value = False
@@ -331,7 +343,7 @@ class TestInstallImageBuilder:
     @patch('kiwi.builder.install.os.chmod')
     def test_create_install_pxe_archive(
         self, mock_chmod, mock_symlink, mock_copy, mock_compress,
-        mock_md5, mock_archive, mock_command, mock_Temporary
+        mock_sha256, mock_archive, mock_command, mock_Temporary
     ):
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
 
@@ -339,7 +351,7 @@ class TestInstallImageBuilder:
         mock_archive.return_value = archive
 
         checksum = mock.Mock()
-        mock_md5.return_value = checksum
+        mock_sha256.return_value = checksum
 
         compress = mock.Mock()
         src = 'target_dir/result-image.x86_64-1.2.3.raw'
@@ -357,11 +369,11 @@ class TestInstallImageBuilder:
         assert mock_command.call_args_list[0] == call(
             ['mv', src, 'tmpdir/result-image.x86_64-1.2.3.xz']
         )
-        mock_md5.assert_called_once_with(
+        mock_sha256.assert_called_once_with(
             'target_dir/result-image.x86_64-1.2.3.raw'
         )
-        checksum.md5.assert_called_once_with(
-            'tmpdir/result-image.x86_64-1.2.3.md5'
+        checksum.sha256.assert_called_once_with(
+            'tmpdir/result-image.x86_64-1.2.3.sha256'
         )
         assert m_open.call_args_list == [
             call('initrd_dir/config.vmxsystem', 'w'),
@@ -435,6 +447,8 @@ class TestInstallImageBuilder:
 
         self.boot_image_task.include_module.assert_any_call('kiwi-dump')
         self.boot_image_task.include_module.assert_any_call('kiwi-dump-reboot')
+        self.boot_image_task.include_driver.assert_any_call('driver1')
+        self.boot_image_task.include_driver.assert_any_call('driver2')
         assert self.boot_image_task.omit_module.call_args_list == [
             call('multipath'), call('module1'), call('module2')
         ]
