@@ -150,7 +150,7 @@ class TestContainerImageOCI:
         mock_oci.unpack.assert_called_once_with()
         mock_oci.sync_rootfs.assert_called_once_with(
             'root_dir', [
-                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                'image', '.kconfig', 'run/*', 'tmp/*',
                 '.buildenv', 'var/cache/kiwi', 'dev/*', 'sys/*', 'proc/*'
             ]
         )
@@ -199,7 +199,7 @@ class TestContainerImageOCI:
         mock_oci.unpack.assert_called_once_with()
         mock_oci.sync_rootfs.assert_called_once_with(
             'root_dir', [
-                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                'image', '.kconfig', 'run/*', 'tmp/*',
                 '.buildenv', 'var/cache/kiwi', 'dev/*', 'sys/*', 'proc/*'
             ]
         )
