@@ -1,6 +1,6 @@
 import io
 from pytest import raises
-from mock import (
+from unittest.mock import (
     patch, MagicMock
 )
 
