@@ -93,10 +93,10 @@ class TestPath:
 
     def test_which_with_real_data(self, pytestconfig: pytest.Config):
         assert Path.which(
-            'tox.ini',
+            'pyproject.toml',
             custom_env={'PATH': str(pytestconfig.rootpath)},
             access_mode=os.F_OK
-        ) == str(pytestconfig.rootpath / "tox.ini")
+        ) == str(pytestconfig.rootpath / "pyproject.toml")
 
         assert Path.which(
             '__init__.py',
@@ -140,3 +140,10 @@ class TestPath:
 
         mock_stat.assert_called_once_with(fname)
         mock_access.assert_called_once_with(fname, mode, effective_ids=True)
+
+    def test_first_exists(self):
+        assert Path.first_exists('/') == '/'
+        assert Path.first_exists('/etc/foo/bar') == '/etc'
+        assert Path.first_exists('artificial') == '.'
+        assert Path.first_exists('foo/bar') == '.'
+        assert Path.first_exists('/x/y/z') == '/'
