@@ -52,6 +52,16 @@ class TestRuntimeChecker:
         with raises(KiwiRuntimeError):
             self.runtime_checker.check_image_include_repos_publicly_resolvable()
 
+    @patch('kiwi.runtime_checker.Command.run')
+    def test_check_target_dir_on_unsupported_filesystem(self, mock_Command_run):
+        stat = Mock()
+        stat.output = 'bogus'
+        mock_Command_run.return_value = stat
+        with raises(KiwiRuntimeError):
+            self.runtime_checker.check_target_dir_on_unsupported_filesystem(
+                '/some/root_dir'
+            )
+
     def test_invalid_target_dir_pointing_to_shared_cache_1(self):
         with raises(KiwiRuntimeError):
             self.runtime_checker.check_target_directory_not_in_shared_cache(
@@ -348,17 +358,6 @@ class TestRuntimeChecker:
             runtime_checker.\
                 check_dracut_module_for_disk_overlay_in_package_list()
 
-    def test_check_efi_mode_for_disk_overlay_correctly_setup(self):
-        self.xml_state.build_type.get_overlayroot = Mock(
-            return_value=True
-        )
-        self.xml_state.build_type.get_firmware = Mock(
-            return_value='uefi'
-        )
-        with raises(KiwiRuntimeError):
-            self.runtime_checker.\
-                check_efi_mode_for_disk_overlay_correctly_setup()
-
     @pytest.mark.parametrize("tool_name, tool_binary", [("isomd5sum", "implantisomd5"), ("checkmedia", "tagmedia")])
     @patch('kiwi.runtime_checker.Path.which')
     @patch('kiwi.runtime_checker.RuntimeConfig')
