@@ -1,4 +1,4 @@
-from mock import patch
+from unittest.mock import patch
 
 from kiwi.system.shell import Shell
 
@@ -7,11 +7,11 @@ from kiwi.defaults import Defaults
 
 class TestShell:
     def test_quote(self):
-        assert Shell.quote('aa\!') == 'aa\\\\\\!'
+        assert Shell.quote(r'aa\!') == 'aa\\\\\\!'
 
     @patch('kiwi.path.Path.which')
     def test_quote_key_value_file(self, mock_which):
-        mock_which.return_value = 'cp'
+        mock_which.side_effect = ['cp', 'bash']
         assert Shell.quote_key_value_file('../data/key_value') == [
             "foo='bar'",
             "bar='xxx'",
